@@ -16,7 +16,9 @@
 
 int main(int argc, char *argv[])
 {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
+#endif
     QApplication app(argc, argv);
     app.setQuitOnLastWindowClosed(false);
 
