@@ -10,7 +10,6 @@
 
 #include "splitter.h"
 
-#include <QMap>
 #include <QObject>
 
 class Terminal;
@@ -56,7 +55,7 @@ public:
     const QString terminalIdList();
     int terminalCount()
     {
-        return m_terminals.count();
+        return m_terminals.size();
     }
     bool hasTerminal(int terminalId);
     Terminal *getTerminal(int terminalId);
@@ -142,7 +141,7 @@ private:
     Splitter *m_baseSplitter;
 
     int m_activeTerminalId;
-    QMap<int, Terminal *> m_terminals;
+    std::map<int, std::unique_ptr<Terminal>> m_terminals;
 
     QString m_title;
 
