@@ -10,14 +10,14 @@
 #include "terminal.h"
 #include "visualeventoverlay.h"
 
-#include <config-yakuake.h>
-
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KNotification>
 
 #include <QDBusConnection>
 
+#include <algorithm>
+
 static bool show_disallow_certain_dbus_methods_message = true;
 
 SessionStack::SessionStack(QWidget *parent)
@@ -51,11 +51,14 @@ int SessionStack::addSessionImpl(Session::SessionType type)
     connect(parentWidget(), SIGNAL(windowClosed()), session, SLOT(reconnectMonitorActivitySignals()));
     // clang-format on
     connect(session, SIGNAL(destroyed(int)), this, SLOT(cleanup(int)));
+    connect(session, &Session::wantsBlurChanged, this, &SessionStack::wantsBlurChanged);
 
     addWidget(session->widget());
 
     m_sessions.insert(session->id(), session);
 
+    Q_EMIT wantsBlurChanged();
+
     if (Settings::dynamicTabTitles())
         Q_EMIT sessionAdded(session->id(), session->title());
     else
@@ -177,6 +180,7 @@ void SessionStack::cleanup(int sessionId)
 
     m_sessions.remove(sessionId);
 
+    Q_EMIT wantsBlurChanged();
     Q_EMIT sessionRemoved(sessionId);
 }
 
@@ -758,3 +762,10 @@ QList<KActionCollection *> SessionStack::getPartActionCollections()
 
     return actionCollections;
 }
+
+bool SessionStack::wantsBlur() const
+{
+    return std::any_of(m_sessions.cbegin(), m_sessions.cend(), [](Session *session) {
+        return session->wantsBlur();
+    });
+}
